ForwardedHeader

Enum ForwardedHeader 

pub enum ForwardedHeader<H: SphinxHeaderSpec> {
    Relayed {
        next_header: RoutingInfo<H>,
        path_pos: u8,
        next_node: H::KeyId,
        additional_info: H::RelayerData,
    },
    Final {
        receiver_data: H::PacketReceiverData,
        is_reply: bool,
        no_ack: bool,
    },
}
Enum carry information about the packet based on whether it is destined for the current node (FinalNode) or if the packet is supposed to be only relayed (RelayNode).

Variants



Relayed

The packet is supposed to be relayed

Fields

next_header: RoutingInfo<H>

Transformed header

path_pos: u8

Position of the relay in the path

next_node: H::KeyId

Public key of the next node

additional_info: H::RelayerData

Additional data for the relayer



Final

The packet is at its final destination

Fields

receiver_data: H::PacketReceiverData

Data from the sender to the packet receiver. This usually contains also H::Pseudonym.

is_reply: bool

Indicates whether this message is a reply and a ReplyOpener should be used to further decrypt the message.

no_ack: bool

Special flag used for acknowledgement signaling.