pub enum ForwardedHeader<H: SphinxHeaderSpec> {
Relayed {
next_header: RoutingInfo<H>,
path_pos: u8,
next_node: H::KeyId,
additional_info: H::RelayerData,
},
Final {
receiver_data: H::PacketReceiverData,
is_reply: bool,
no_ack: bool,
},
}Expand description
Enum carry information about the packet based on whether it is destined for the current node (FinalNode)
or if the packet is supposed to be only relayed (RelayNode).
Variants
Relayed
The packet is supposed to be relayed
Fields

next_header: RoutingInfo<H>Transformed header

additional_info: H::RelayerDataAdditional data for the relayer
Final
The packet is at its final destination
Fields

receiver_data: H::PacketReceiverDataData from the sender to the packet receiver.
This usually contains also H::Pseudonym.

is_reply: boolIndicates whether this message is a reply and a ReplyOpener
should be used to further decrypt the message.